@@ -18,7 +18,7 @@ def init(file_enable = True,file_name = int(time.time()),dir_name = "logs"):
 def _log(msg,level = 0,f = "Main Thread"):
     global file
     if file == None:
-        _init()   
+        init()   
 
     if level == 0:
         l = "INFO"
